"""
cBioPortal_get_genes

Search for genes by keyword or query (gene symbol or alias). Alias: cBioPortal_search.
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def cBioPortal_get_genes(
    keyword: Optional[str] = None,
    query: Optional[str] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> list[Any]:
    """
    Search for genes by keyword or query (gene symbol or alias). Alias: cBioPortal_search.

    Parameters
    ----------
    keyword : str
        Gene symbol or alias to search for (e.g., 'BRCA1', 'TP53')
    query : str
        Alias for keyword: gene symbol or alias to search for
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    list[Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v for k, v in {"keyword": keyword, "query": query}.items() if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "cBioPortal_get_genes",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["cBioPortal_get_genes"]
